@@ -1,5 +1,5 @@
 """
-
+.. todo:: Document :mod:`royalnet_discordpy.pda`.
 """
 
 from __future__ import annotations
@@ -58,10 +58,10 @@ class DiscordPDA(discord.AutoShardedClient):
         raise
 
     async def on_message(self, message: discord.Message):
-        log.debug(f"Received a new message: {message}")
+        log.debug(f"Received a new message: {message!r}")
 
         if message.type != discord.MessageType.default:
-            log.debug(f"Ignoring message because type is: {message.type}")
+            log.debug(f"Ignoring message because type is: {message.type!r}")
             return
 
         author: t.Union[discord.User, discord.Member] = message.author
@@ -69,8 +69,13 @@ class DiscordPDA(discord.AutoShardedClient):
             log.debug(f"Ignoring message from myself")
             return
 
+        log.debug(f"Creating DiscordMessage from: {message!r}")
         bullet = bullets.DiscordMessage(_msg=message)
+
+        log.debug(f"Getting the channel of: {bullet!r}")
         channel = await bullet.channel()
+
+        log.debug(f"Putting bullet {bullet!r} in channel {channel!r}")
         await self.put_bullet(channel=channel, bullet=bullet)
 
     def register_conversation(self, conv: engi.Conversation) -> None:
@@ -91,18 +96,19 @@ class DiscordPDA(discord.AutoShardedClient):
         log.info(f"Unregistering conversation: {conv!r}")
         self.conversations.remove(conv)
 
-    def register_partial(self, part: engi.PartialCommand) -> engi.Command:
+    def register_partial(self, part: engi.PartialCommand, names: t.List[str]) -> engi.Command:
         """
         Register a new :class:`PartialCommand` in the PDA, converting it to a :class:`Command` in the process.
 
         :param part: The :class:`PartialCommand` to register.
+        :param names: The :attr:`~royalnet.engineer.Command.names` to register the command as.
         :return: The resulting :class:`Command`.
         """
         log.debug(f"Completing partial: {part!r}")
         if part.syntax:
-            command = part.complete(r"^!{name}\s+{syntax}$")
+            command = part.complete(pattern=r"^!{name}\s+{syntax}$", names=names)
         else:
-            command = part.complete(r"^!{name}$")
+            command = part.complete(pattern=r"^!{name}$", names=names)
         self.register_conversation(command)
         return command
 
@@ -113,10 +119,10 @@ class DiscordPDA(discord.AutoShardedClient):
         :param channel: The channel associated to the dispenser the bullet should be put in.
         :param bullet: The bullet to put in the dispenser.
         """
-        log.debug(f"Finding dispenser for channel: {channel}")
+        log.debug(f"Finding dispenser for channel: {channel!r}")
         dispenser = self.dispensers.get(hash(channel))
         if not dispenser:
-            log.debug(f"Dispenser not found, creating one")
+            log.debug(f"Dispenser not found, creating one...")
             dispenser = engi.Dispenser()
             self.dispensers[hash(channel)] = dispenser
 
@@ -124,11 +130,11 @@ class DiscordPDA(discord.AutoShardedClient):
         loop = asyncio.get_running_loop()
 
         for conversation in self.conversations:
-            log.debug(f"Creating run task for: {conversation}")
+            log.debug(f"Creating run task for: {conversation!r}")
             loop.create_task(dispenser.run(conversation), name=f"{repr(conversation)}")
 
         log.debug("Running a event loop cycle...")
         await asyncio.sleep(0)
 
-        log.debug(f"Putting bullet in dispenser: {bullet}")
+        log.debug(f"Putting bullet {bullet!r} in dispenser {dispenser!r}...")
         await dispenser.put(bullet)
